@@ -734,6 +734,14 @@ void send_print(GtkWidget * button, gpointer ppd)
 	  /* not a PS file */
 	  if (in_path("a2ps")) {
 	    command_line = g_strdup("a2ps -1 -o - ");
+	    extern GtkWidget *border_toggle;
+	    extern GtkWidget *header_toggle;
+	    if (!gtk_toggle_button_get_active (header_toggle))
+	      command_line =
+		g_strconcat(command_line," -B ",NULL);
+	    if (!gtk_toggle_button_get_active (border_toggle))
+	      command_line =
+		g_strconcat(command_line,"  --borders=no ",NULL);
 	    command_line =
 	      g_strconcat(command_line, quoted_filename, " ", NULL);
 	    command_line = g_strconcat(command_line, "| ppdfilt -p ", NULL);
